
.. _sec-scripts:

******************
Command-line tools
******************

Gstat
-----

.. automodule:: GooseSLURM.cli.Gstat

Ginfo
-----

.. automodule:: GooseSLURM.cli.Ginfo

Gps
---

.. automodule:: GooseSLURM.cli.Gps

.. _scripts_Gsub:

Gsub
----

.. automodule:: GooseSLURM.cli.Gsub

Gdel
----

.. automodule:: GooseSLURM.cli.Gdel

Gacct
-----

.. argparse::
    :module: GooseSLURM.sacct
    :func: cli_parser
    :prog: Gacct
